@@ -1,9 +1,9 @@
 package WordList;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-01'; # DATE
+our $DATE = '2020-05-02'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.5.0'; # VERSION
+our $VERSION = '0.5.1'; # VERSION
 
 use strict 'subs', 'vars';
 
@@ -32,6 +32,25 @@ sub each_word {
     }
 }
 
+sub next_word {
+    my $self = shift;
+
+    my $class = ref($self);
+    my $fh = \*{"$class\::DATA"};
+    my $word = <$fh>;
+    chomp $word if defined $word;
+    $word;
+}
+
+sub first_word {
+    my $self = shift;
+
+    my $class = ref($self);
+    my $fh = \*{"$class\::DATA"};
+    seek $fh, ${"$class\::DATA_POS"}, 0;
+    $self->next_word;
+}
+
 sub pick {
     my ($self, $n) = @_;
 
@@ -111,7 +130,7 @@ WordList - Word lists
 
 =head1 VERSION
 
-This document describes version 0.5.0 of WordList (from Perl distribution WordList), released on 2020-05-01.
+This document describes version 0.5.1 of WordList (from Perl distribution WordList), released on 2020-05-02.
 
 =head1 SYNOPSIS
 
@@ -202,6 +221,15 @@ first argument.
 
 If code return -2 will exit early.
 
+=head2 first_word
+
+Another way to iterate the word list is by calling L</first_word> to get the
+first word, then L</next_word> repeatedly until you get C<undef>.
+
+=head2 next_word
+
+Get the next word. See L</first_word> for more details.
+
 =head2 pick
 
 Usage:
